nntsmeasureslocationdispersion: Moments of an NNTS density
Description
Computes the first moment, second moment, mean direction, dispersion, circular varance, coefficient of
asymmetry and kurtosis from the given parameters of an NNTS density.
Usage
nntsmeasureslocationdispersion(cestimates,M=0)
Value
firstmoment
Value of the first trigonometric moment
secondmoment
Value of the second trigonometric moment
meandirection
Value of the mean direction
dispersion
Value of the dispersion
circularvariance
Value of the circular variance
asymmetrycoefficient
Value of the coefficient of asymmetry
kurtosis
Value of the kurtosis
Arguments
cestimates
Matrix of (M+1)x2. The first column is the parameter numbers, and the second column is the c parameter vecto (or c estimates) of the NNTS model
M
Number of components in the NNTS density
Author
Juan Jose Fernandez-Duran y Maria Mercedes Gregorio-Dominguez
References
Fernández-Durán, J.J., Gregorio-Domínguez, M.M. (2025). Multimodal Symmetric Circular Distributions Based on Nonnegative Trigonometric Sums and a Likelihood Ratio Test for Reflective Symmetry, arXiv:2412.19501 [stat.ME]
(available at https://arxiv.org/abs/2412.19501)